/* diversity-rae-backend.c -
 *
 * Copyright 2008 Openmoko, Inc.
 * Authored by Chia-I Wu <olv@openmoko.com>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */

#include <glib.h>
#include <diversity-module.h>
#include <diversity-world.h>
#include "diversity-rae.h"

static struct {
	DiversityRae *eqp;
} rae;

static void rae_fini(void)
{
	if (rae.eqp) {
		g_object_unref(rae.eqp);
		rae.eqp = NULL;
	}
}

static gint rae_init(DiversityWorld *world, GError **error)
{
	DiversityBard *self;

	if (!g_thread_supported())
		g_thread_init(NULL);

	rae.eqp = diversity_rae_new(world, error);
	if (!rae.eqp)
		return FALSE;

	self = diversity_world_get_self(world);
	diversity_bard_add_equipment(self,
			DIVERSITY_EQUIPMENT(rae.eqp));

	return TRUE;
}

DiversityModuleHandle _diversity_module_handle_rae = {
	.version = DIVERSITY_MODULE_HANDLE_VERSION,
	.name = "Rae",

	.init = rae_init,
	.fini = rae_fini,
};
